@@ -26,7 +26,8 @@ class UserTestCase(TestCase):
         email2 = "cenerentola@disney.com"
         password2 = "renecentola"
 
-        self.admin_user = User.objects.create_user(username='admin', email='admin@example.com', password='admin')
+        self.admin_user = User.objects.create_user(username='admin', email='admin@example.com', password='admin',
+                                                   is_superuser=True, is_staff=True)
 
         self.service = Service.objects.create(service_url='http://example.com', name='example.com')
         self.service2 = Service.objects.create(service_url='http://disney.org', name='disney.org',
