@@ -394,9 +394,9 @@ if USE_TZ:
     # http://docs.celeryproject.org/en/latest/userguide/configuration.html#std:setting-timezone
     CELERY_TIMEZONE = TIME_ZONE
 
-# http://docs.celeryproject.org/en/latest/userguide/configuration.html#std:setting-broker_url
-CELERY_BROKER_URL = env("CELERY_BROKER_URL")
 # pai
+# http://docs.celeryproject.org/en/latest/userguide/configuration.html#std:setting-broker_url
+#CELERY_BROKER_URL = env("CELERY_BROKER_URL")
 ## http://docs.celeryproject.org/en/latest/userguide/configuration.html#std:setting-result_backend
 #CELERY_RESULT_BACKEND = CELERY_BROKER_URL
 
@@ -424,6 +424,10 @@ CELERY_TASK_SOFT_TIME_LIMIT = 60
 # http://docs.celeryproject.org/en/latest/userguide/configuration.html#beat-scheduler
 CELERY_BEAT_SCHEDULER = "django_celery_beat.schedulers:DatabaseScheduler"
 
+# pai
+# enable task state monitoring
+CELERY_TRACK_STARTED = True
+
 # django-reset-framework
 # -------------------------------------------------------------------------------
 # django-rest-framework - https://www.django-rest-framework.org/api-guide/settings/
