@@ -14,11 +14,14 @@ from django.conf import settings
 from django.utils.translation import gettext_lazy as _
 from django.core.exceptions import SuspiciousOperation
 
+from rest_framework.renderers import JSONRenderer
+
 from allauth.account.adapter import DefaultAccountAdapter
 from allauth.account import app_settings as allauth_app_settings
 
 from .mixins import TryAuthenticateMixin
 from .utils import set_session_key, check_user_can_login
+from .exceptions import UnsubscribedUserException, DectivatedUserException, AdminUserCanNotLoginException
 from .apps.emails.models import EmailAddress
 from .apps.devices.models import Device
 from .apps.devices.utils import get_request_device
@@ -56,6 +59,14 @@ class AccountAdapter(DefaultAccountAdapter, TryAuthenticateMixin):
 
         return is_ajax
 
+    def ajax_response(self, request, response, redirect_to=None, form=None, data=None):
+        # manually setting response renderer
+        setattr(response, 'accepted_renderer', JSONRenderer())
+        setattr(response, 'accepted_media_type', 'application/json')
+        setattr(response, 'renderer_context', {})
+
+        return super(AccountAdapter, self).ajax_response(request, response, redirect_to, form, data)
+
     def get_login_redirect_url(self, request):
         """
         Returns the default URL to redirect to after logging in.  Note
@@ -167,16 +178,31 @@ class AccountAdapter(DefaultAccountAdapter, TryAuthenticateMixin):
         else:
             self.authentication_failed(request, **credentials)
 
-        if is_authenticated(user):
-            logger.info('adapter authenticated "{}"'.format(user))
-            _profile = get_or_create_user_profile(user, Profile)
+        # check user can login
+        authentication_success = False
 
-            # check unsubscription
+        try:
+            check_user_can_login(user)
+
+        except UnsubscribedUserException:
             user_unsubscribed_at = user.sso_app_profile.unsubscribed_at
             if user_unsubscribed_at is not None:
                 set_session_key(request, '__django_sso_app__user_is_unsubscribed', str(user_unsubscribed_at))
 
-        return user
+        except Exception as e:
+            logger.exception('adapter authentication failed "{}"'.format(str(e)))
+
+        else:
+            authentication_success = True
+
+        if authentication_success:
+            if is_authenticated(user):
+                logger.info('adapter authenticated "{}"'.format(user))
+                _profile = get_or_create_user_profile(user, Profile)
+
+                return user
+        else:
+            self.authentication_failed(request, **credentials)
 
     def update_user_profile(self, user, cleaned_data, commit=True):
         logger.debug('adapter update user profile')
