@@ -29,6 +29,13 @@ class AppSettings(object):
                          lambda name, dflt: getattr(settings, name, self._env(name, dflt, type)))
         return getter(name, dflt)
 
+    def _allauth_setting(self, name, dflt):
+        from django.conf import settings
+        getter = getattr(settings,
+                         'ALLAUTH_SETTING_GETTER',
+                         lambda name, dflt: getattr(settings, name, dflt))
+        return getter(self.prefix + name, dflt)
+
     def _setting(self, name, dflt, type=str):
         from django.conf import settings
         getter = getattr(settings,
@@ -306,15 +313,19 @@ class AppSettings(object):
 
     @property
     def STAFF_USER_GROUPS(self):
-        return self._django_setting('STAFF_USER_GROUPS', ['staff'], list)
+        return self._setting('STAFF_USER_GROUPS', ['staff'], list)
 
     @property
     def TEST_USER_USERNAME(self):
-        return self._django_setting('TEST_USER_USERNAME', 'user')
+        return self._setting('TEST_USER_USERNAME', 'user')
 
     @property
     def TEST_USER_EMAIL(self):
-        return self._django_setting('TEST_USER_EMAIL', 'user@example.com')
+        return self._setting('TEST_USER_EMAIL', 'user@example.com')
+
+    @property
+    def LOGOUT_DELETES_ALL_PROFILE_DEVICES(self):
+        return self._setting('LOGOUT_DELETES_ALL_PROFILE_DEVICES', True, bool)
 
 
 # Ugly? Pennersr says Guido recommends this himself ...
