@@ -8,6 +8,8 @@ from rest_framework import status
 
 from django_sso_app.backend.tests.factories import UserTestCase
 
+from .... import app_settings
+
 User = get_user_model()
 
 
@@ -86,6 +88,19 @@ class TestProfileUpdate(UserTestCase):
         self.assertEqual(unverified_payload2.get('sso_rev'), unverified_payload.get('sso_rev') + 1,
                          'rev not incremented in cookie')
 
+        profile_object = self.valid_profile_update
+        for f in app_settings.PROFILE_FIELDS:
+            model_val = getattr(self.user.sso_app_profile, f, None)
+            object_val = profile_object.get(f, None)
+
+            if f == 'birthdate':
+                model_val = str(model_val)
+            elif f == 'country':
+                object_val = object_val.upper()
+                model_val = str(model_val).upper()
+
+            self.assertEqual(model_val, object_val)
+
 
 class TestCompleteUnsubscription(UserTestCase):
 
