@@ -5,7 +5,6 @@ from django.contrib.auth import logout, get_user_model
 from django.shortcuts import reverse, redirect
 from django.urls import reverse_lazy
 from django.views.generic.edit import UpdateView
-from django.core.exceptions import SuspiciousOperation
 
 from rest_framework import permissions
 from rest_framework import status
@@ -20,9 +19,7 @@ from ... import app_settings
 
 from ...permissions import is_staff, is_authenticated
 from ...utils import invalidate_cookie
-from ...tokens.utils import get_request_jwt
 from ...mixins import TryAuthenticateMixin, WebpackBuiltTemplateViewMixin
-from ...tokens.utils import renew_response_jwt
 
 User = get_user_model()
 
@@ -33,17 +30,24 @@ class ProfileView(WebpackBuiltTemplateViewMixin):
     template_name = "account/profile.html"
 
     def get_object(self, queryset=None):
-        return self.request.user.sso_app_profile
+        request_user = getattr(self.request, 'user', None)
+
+        if is_authenticated(request_user):
+            return request_user.get_sso_app_profile()
+
 
     def get_context_data(self, *args, **kwargs):
+        context = super(ProfileView, self).get_context_data(*args, **kwargs)
         self.object = self.get_object()
 
-        context = super(ProfileView, self).get_context_data(*args, **kwargs)
-        user = self.object
-        user_fields = []
-        for field in app_settings.PROFILE_FIELDS:
-            user_fields.append((field, getattr(user, field)))
-        context['user_fields'] = user_fields
+        if self.object is not None:
+            profile = self.object
+
+            user_fields = []
+            for field in app_settings.PROFILE_FIELDS:
+                user_fields.append((field, getattr(profile, field)))
+
+            context['user_fields'] = user_fields
 
         return context
 
@@ -64,7 +68,10 @@ class ProfileUpdateView(UpdateView, WebpackBuiltTemplateViewMixin):
     success_url = reverse_lazy('profile.update')
 
     def get_object(self, queryset=None):
-        return self.request.user.sso_app_profile
+        request_user = getattr(self.request, 'user', None)
+
+        if is_authenticated(request_user):
+            return request_user.get_sso_app_profile()
 
     def get_context_data(self, *args, **kwargs):
         self.object = self.get_object()
@@ -101,21 +108,10 @@ class ProfileUpdateView(UpdateView, WebpackBuiltTemplateViewMixin):
             raise
 
         else:
-            received_jwt = get_request_jwt(request)
-            logger.info('Updating JWT: {}'.format(received_jwt))
-
-            requesting_user = self.request.user
             user = profile.user
+            adapter = get_adapter(request)
 
-            if requesting_user == user:
-                if not is_staff(requesting_user):
-                    logger.info('User "{}" updated profile, updating response JWT'.format(user))
-
-                    renew_response_jwt(received_jwt, user, request, response)
-            else:
-                _msg = 'User "{}" tried to updated profile for "{}"'.format(requesting_user, user)
-                logger.warning(_msg)
-                raise SuspiciousOperation(_msg)
+            adapter.try_update_response_jwt(user, response)
 
             return response
 
@@ -164,27 +160,16 @@ class ProfileApiViewSet(viewsets.ModelViewSet):
         logger.info('Profile partial_update status code is {}, {}'.format(response_status_code, request.data))
 
         if response_status_code == 200:
-            received_jwt = get_request_jwt(request)
-            logger.info('Updating JWT: {}'.format(received_jwt))
-
-            requesting_user = self.request.user
             profile = self.get_object()
             user = profile.user
 
-            from_browser_as_same_user = received_jwt is not None and requesting_user == user
-
-            if from_browser_as_same_user:
-                logger.info('User "{}" updated profile, updating response JWT'.format(user))
-
-                renew_response_jwt(received_jwt, user, request, response)
-            else:
-                logger.warning('User "{}" tried to updated profile for "{}"'.format(requesting_user, user))
+            adapter = get_adapter(request)
+            adapter.try_update_response_jwt(user, response)
 
         return response
 
 
-class ProfileCompleteUnsubscriptionApiView(TryAuthenticateMixin,
-                                           viewsets.GenericViewSet):
+class ProfileCompleteUnsubscriptionApiView(viewsets.GenericViewSet):
     """
     Completely unsubscribe user
     """
@@ -207,34 +192,23 @@ class ProfileCompleteUnsubscriptionApiView(TryAuthenticateMixin,
         if not serializer.is_valid():
             return Response(serializer.errors, status=status.HTTP_400_BAD_REQUEST)
 
+        adapter = get_adapter(request)
+
         username = requesting_user.username
         email = requesting_user.email
         password = serializer.data.get('password')
 
-        has_unsubscribed = False
-        unsubscribing_user = self.try_authenticate(username, email, password)
+        try:
+            adapter.try_completely_unsubscribe(username, email, password)
 
-        logger.info('User {} wants to unregister from SSO'.format(unsubscribing_user))
+        except:
+            logger.exception('completely_unsubscribe error')
+            response = Response('Error unsubscribing completely', status=status.HTTP_500_INTERNAL_SERVER_ERROR)
 
-        if unsubscribing_user == requesting_user:
-            adapter = get_adapter(request)
-
-            has_unsubscribed = adapter.completely_unsubscribe(unsubscribing_user)
-
-            if has_unsubscribed:
-                response = Response('Successfully completely unsubscribed.', status=status.HTTP_200_OK)
-            else:
-                response = Response('Error completely unsubscribing', status=status.HTTP_500_INTERNAL_SERVER_ERROR)
         else:
-            logger.error('User {} tried to unregister user {} from SSO'.format(requesting_user, unsubscribing_user))
+            response = Response('Successfully completely unsubscribed.', status=status.HTTP_200_OK)
 
-            response = Response('Not authorized.', status=status.HTTP_401_UNAUTHORIZED)
-
-        if has_unsubscribed:
-            invalidate_cookie(response, app_settings.JWT_COOKIE_NAME)
-
-            if (hasattr(request, 'session')):
-                logout(request)
+        invalidate_cookie(response, app_settings.JWT_COOKIE_NAME)
 
         return response
 
@@ -243,7 +217,7 @@ class ProfileDetailApiView(generics.RetrieveAPIView):
     """
     Profile detail entrypoint
     """
-    
+
     lookup_field = 'sso_id'
     serializer_class = ProfileSerializer
 
@@ -253,5 +227,4 @@ class ProfileDetailApiView(generics.RetrieveAPIView):
     def get_object(self, *args, **kwargs):
         user = getattr(self.request, 'user', None)
 
-        if user is not None and not is_staff(user):
-            return user.sso_app_profile
+        return user.sso_app_profile
