@@ -16,8 +16,9 @@ def check_upated_fields(sender, instance, created, **kwargs):
 
     if created:  # not instance._state.adding:  # if instance.pk:
         logger.info('Subsciption created, doing nothing')
-
     else:
-        if instance.is_unsubscribed or not instance.is_active:
+        subscription = instance
+        if subscription.is_unsubscribed or not subscription.is_active:
             logger.info('Subsciption updates profile rev')
-            instance.profile.update_rev(True)
+
+            subscription.profile.update_rev(True)
