@@ -4,13 +4,13 @@ from django.contrib.auth import get_user_model
 from django import forms
 
 from allauth.account.adapter import get_adapter
-from allauth.account.models import EmailAddress
 from rest_framework import serializers
 
 from ...utils import set_session_key
 from ... import app_settings
 from ...permissions import is_staff
 from ...serializers import AbsoluteUrlSerializer
+from ..emails.models import EmailAddress
 from ..profiles.models import Profile
 from ..profiles.utils import update_profile
 from ..profiles.serializers import ProfileSerializer
@@ -179,46 +179,32 @@ class UserSerializer(AbsoluteUrlSerializer):
 
         if (new_email is not None) and (new_email != user.email):
 
-            logger.info('user "{}" is changing email for user "{}"'.format(requesting_user,
+            logger.info('User "{}" is changing email for user "{}"'.format(requesting_user,
                                                                            user))
 
-            restore_as_primary = False
 
-            try:
-                adapter.validate_unique_email(new_email)
+            adapter.validate_unique_email(new_email)
 
-            except forms.ValidationError:
-                if EmailAddress.objects.filter(email__iexact=new_email).first() is not None:
-                    logger.info('User "{}" wants to reset email "{}" as primary'.format(requesting_user, new_email))
-                    restore_as_primary = True
-                    must_confirm_email = False
-                else:
-                    # email already taken
-                    raise
+            created_email = EmailAddress.objects.add_email(request, user,
+                                                           new_email,
+                                                           confirm=must_confirm_email)
 
-            if not restore_as_primary:
-                created_email = EmailAddress.objects.add_email(request, user,
-                                                               new_email,
-                                                               confirm=must_confirm_email)
-
-                logger.info('A new user EmailAddress for user "{}" has been created ({})'.format(user,
-                                                                                                 created_email.id))
+            logger.info('A new user EmailAddress for user "{}" has been created ({})'.format(user,
+                                                                                             created_email.id))
 
             if must_confirm_email:
-                adapter.unconfirm_all_user_emails(user)
-
                 logger.info('"{}" must confirm email "{}"'.format(user, new_email))
             else:
-                if not restore_as_primary:
-                    adapter.confirm_email(None, created_email)
+                logger.info('confirming email "{}"'.format(new_email))
+                created_email.verified = True
+                created_email.set_as_primary(conditional=False)
 
             user.email = new_email  # set user model email
 
-            if not restore_as_primary:
-                setattr(user, '__django_sso_app__email_updated', True)
-                set_session_key(request, '__django_sso_app__user_email_updated', True)
+            setattr(user, '__django_sso_app__email_updated', True)
+            set_session_key(request, '__django_sso_app__user_email_updated', True)
 
-        if (new_password is not None):
+        if new_password is not None:
             logger.info('user "{}" is changing password for user "{}"'.format(requesting_user,
                                                                               user))
 
