@@ -7,10 +7,9 @@ from django.db import transaction
 from django.utils.encoding import smart_str
 from django.contrib.auth import get_user_model
 
-from allauth.account.models import EmailAddress
-
 from ... import app_settings
 from ..api_gateway.kong.functions import get_apigateway_sso_id
+from ..emails.models import EmailAddress
 from ..profiles.utils import update_profile, get_or_create_user_profile
 from ..profiles.models import Profile
 
