@@ -7,12 +7,13 @@ def is_authenticated(user):
 
 
 def is_staff(user):
-    if user is not None and user.is_staff:
-        return True
+    if user is not None:
+        if user.is_staff:
+            return True
 
-    profile = getattr(user, 'sso_app_profile', None)
-    if profile is not None:
-        return profile.groups.filter(name__in=app_settings.STAFF_USER_GROUPS).count() > 0
+        profile = getattr(user, 'sso_app_profile', None)
+        if profile is not None:
+            return profile.groups.filter(name__in=app_settings.STAFF_USER_GROUPS).count() > 0
 
     return False
 
