@@ -104,6 +104,28 @@ class TestLogin(UserTestCase):
         self.assertFalse(has_jwt_cookie, 'admin receives jwt')
         self.assertEqual(jwt_cookie, None, 'jwt is still valid')
 
+    def test_admin_user_can_not_login_from_default_views(self):
+        response = self.client.post(
+            reverse('account_login'),
+            data=self.valid_admin_login
+        )
+
+        cookies = response.client.cookies.items()
+
+        jwt_cookie = None
+        has_jwt_cookie = False
+        for (key, val) in cookies:
+            if key == "jwt":
+                has_jwt_cookie = True
+                jwt_cookie = val
+                break
+
+        self.assertEqual(response.status_code, status.HTTP_200_OK)
+
+        self.assertFalse(has_jwt_cookie, 'admin receives jwt')
+        self.assertEqual(jwt_cookie, None, 'jwt is still valid')
+
+
 
 class TestLogout(UserTestCase):
 
