@@ -6,8 +6,8 @@ import base64
 
 from django.core.management.utils import get_random_secret_key
 
-from .exceptions import ProfileIncompleteException, DectivatedUserException, UnsubscribedUserException
-from .permissions import is_staff, is_authenticated
+from .exceptions import ProfileIncompleteException, DectivatedUserException, UnsubscribedUserException, AdminUserCanNotLoginException
+from .permissions import is_authenticated
 from . import app_settings
 
 # initializing seed
@@ -96,8 +96,10 @@ def check_user_can_login(user):
     :return:
     """
 
-    if is_authenticated(user) and not user.is_superuser:
-        if not user.is_active:
+    if is_authenticated(user):
+        if user.is_superuser:
+            raise AdminUserCanNotLoginException()
+        elif not user.is_active:
             raise DectivatedUserException()
         else:
             if user.sso_app_profile.is_unsubscribed:
